==> aws-cdk-scala_2.13-0.14.0-sources.jar: io/burkard/cdk/services/ecs/patterns/NetworkLoadBalancedTaskImageProps.scala <==
package io.burkard.cdk.services.ecs.patterns

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object NetworkLoadBalancedTaskImageProps {

  def apply(
    image: software.amazon.awscdk.services.ecs.ContainerImage,
    containerName: Option[String] = None,
    secrets: Option[Map[String, _ <: software.amazon.awscdk.services.ecs.Secret]] = None,
    executionRole: Option[software.amazon.awscdk.services.iam.IRole] = None,
    taskRole: Option[software.amazon.awscdk.services.iam.IRole] = None,
    logDriver: Option[software.amazon.awscdk.services.ecs.LogDriver] = None,
    containerPorts: Option[List[_ <: Number]] = None,
    enableLogging: Option[Boolean] = None,
    environment: Option[Map[String, String]] = None,
    dockerLabels: Option[Map[String, String]] = None,
    family: Option[String] = None
  ): software.amazon.awscdk.services.ecs.patterns.NetworkLoadBalancedTaskImageProps =
    (new software.amazon.awscdk.services.ecs.patterns.NetworkLoadBalancedTaskImageProps.Builder)
      .image(image)
      .containerName(containerName.orNull)
      .secrets(secrets.map(_.asJava).orNull)
      .executionRole(executionRole.orNull)
      .taskRole(taskRole.orNull)
      .logDriver(logDriver.orNull)
      .containerPorts(containerPorts.map(_.asJava).orNull)
      .enableLogging(enableLogging.map(Boolean.box).orNull)
      .environment(environment.map(_.asJava).orNull)
      .dockerLabels(dockerLabels.map(_.asJava).orNull)
      .family(family.orNull)
      .build()
}

==> aws-cdk-scala_3-0.7.0-sources.jar: io/burkard/cdk/services/ecs/patterns/NetworkLoadBalancedTaskImageProps.scala <==
package io.burkard.cdk.services.ecs.patterns

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object NetworkLoadBalancedTaskImageProps {

  def apply(
    image: software.amazon.awscdk.services.ecs.ContainerImage,
    containerName: Option[String] = None,
    secrets: Option[Map[String, _ <: software.amazon.awscdk.services.ecs.Secret]] = None,
    executionRole: Option[software.amazon.awscdk.services.iam.IRole] = None,
    taskRole: Option[software.amazon.awscdk.services.iam.IRole] = None,
    logDriver: Option[software.amazon.awscdk.services.ecs.LogDriver] = None,
    containerPorts: Option[List[_ <: Number]] = None,
    enableLogging: Option[Boolean] = None,
    environment: Option[Map[String, String]] = None,
    dockerLabels: Option[Map[String, String]] = None,
    family: Option[String] = None
  ): software.amazon.awscdk.services.ecs.patterns.NetworkLoadBalancedTaskImageProps =
    (new software.amazon.awscdk.services.ecs.patterns.NetworkLoadBalancedTaskImageProps.Builder)
      .image(image)
      .containerName(containerName.orNull)
      .secrets(secrets.map(_.asJava).orNull)
      .executionRole(executionRole.orNull)
      .taskRole(taskRole.orNull)
      .logDriver(logDriver.orNull)
      .containerPorts(containerPorts.map(_.asJava).orNull)
      .enableLogging(enableLogging.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .environment(environment.map(_.asJava).orNull)
      .dockerLabels(dockerLabels.map(_.asJava).orNull)
      .family(family.orNull)
      .build()
}
